==> react-horizontal-router-dom-4.2.14.tgz: package/es/Link.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import PropTypes from "prop-types";
import invariant from "invariant";
import warning from "warning";
import { createLocation } from "history";

var isModifiedEvent = function isModifiedEvent(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
};

/**
 * The public API for rendering a history-aware <a>.
 */

var Link = function (_React$Component) {
  _inherits(Link, _React$Component);

  function Link() {
    var _temp, _this, _ret;

    _classCallCheck(this, Link);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.handleClick = function (event) {
      if (_this.props.onClick) _this.props.onClick(event);

      if (!event.defaultPrevented && // onClick prevented default
      event.button === 0 && // ignore everything but left clicks
      !_this.props.target && // let browser handle "target=_blank" etc.
      !isModifiedEvent(event) // ignore clicks with modifier keys
      ) {
          event.preventDefault();

          var history = _this.context.router.history;
          var horizontalRouter = _this.context.horizontalRouter;
          var _this$props = _this.props,
              replace = _this$props.replace,
              horizontal = _this$props.horizontal;
          var to = _this.props.to;


          if (horizontalRouter && horizontal) {
            var action = "open";
            if (to === false) {
              to = _this.context.horizontalRouter.prevPath;
              action = "close";
            }

            if (replace) {
              history.replace(to, {
                horizontalRoute: true,
                action: action,
                horizontalRouteId: _this.context.horizontalRouter.horizontalRouteId
              });
            } else {
              history.push(to, {
                horizontalRoute: true,
                action: action,
                horizontalRouteId: _this.context.horizontalRouter.horizontalRouteId
              });
            }
          } else {
            if (replace) {
              history.replace(to);
            } else {
              history.push(to);
            }
          }
        }
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Link.prototype.render = function render() {
    var _props = this.props,
        replace = _props.replace,
        to = _props.to,
        innerRef = _props.innerRef,
        children = _props.children,
        horizontal = _props.horizontal,
        dontRenderComponent = _props.dontRenderComponent,
        props = _objectWithoutProperties(_props, ["replace", "to", "innerRef", "children", "horizontal", "dontRenderComponent"]);

    invariant(this.context.router, "You should not use <Link> outside a <Router>");

    warning(!(horizontal && !this.context.horizontalRouter), "Horizontal Link will not work outside a <HorizontalSwitch> component");

    invariant(to !== undefined, 'You must specify the "to" property');

    var history = this.context.router.history;

    var location = typeof to === "string" ? createLocation(to, null, null, history.location) : to;

    var href = history.createHref(location);
    if (React.isValidElement(this.props.children) && dontRenderComponent) {
      return React.cloneElement(children, { onClick: this.handleClick });
    }
    return React.createElement("a", _extends({}, props, { onClick: this.handleClick, href: href, ref: innerRef }));
  };

  return Link;
}(React.Component);

Link.propTypes = {
  onClick: PropTypes.func,
  children: PropTypes.node,
  target: PropTypes.string,
  horizontal: PropTypes.bool,
  dontRenderComponent: PropTypes.bool,
  replace: PropTypes.bool,
  to: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.bool]).isRequired,
  innerRef: PropTypes.oneOfType([PropTypes.string, PropTypes.func])
};
Link.defaultProps = {
  replace: false
};
Link.contextTypes = {
  router: PropTypes.shape({
    history: PropTypes.shape({
      push: PropTypes.func.isRequired,
      replace: PropTypes.func.isRequired,
      createHref: PropTypes.func.isRequired
    }).isRequired
  }).isRequired,
  horizontalRouter: PropTypes.shape({
    horizontalRouteId: PropTypes.number,
    prevPath: PropTypes.string
  })
};


export default Link;

==> react-horizontal-router-dom-4.2.16.tgz: package/es/Link.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import PropTypes from "prop-types";
import invariant from "invariant";
import warning from "warning";
import { createLocation } from "history";

var isModifiedEvent = function isModifiedEvent(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
};

/**
 * The public API for rendering a history-aware <a>.
 */

var Link = function (_React$Component) {
  _inherits(Link, _React$Component);

  function Link() {
    var _temp, _this, _ret;

    _classCallCheck(this, Link);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.handleClick = function (event) {
      if (_this.props.onClick) _this.props.onClick(event);

      if (!event.defaultPrevented && // onClick prevented default
      event.button === 0 && // ignore everything but left clicks
      !_this.props.target && // let browser handle "target=_blank" etc.
      !isModifiedEvent(event) // ignore clicks with modifier keys
      ) {
          event.preventDefault();

          var history = _this.context.router.history;
          var horizontalRouter = _this.context.horizontalRouter;
          var _this$props = _this.props,
              replace = _this$props.replace,
              horizontal = _this$props.horizontal;
          var to = _this.props.to;


          if (horizontalRouter && horizontal) {
            var action = "open";
            if (to === false) {
              to = _this.context.horizontalRouter.prevPath;
              action = "close";
            }

            if (replace) {
              history.replace(to, {
                horizontalRoute: true,
                action: action,
                horizontalRouteId: _this.context.horizontalRouter.horizontalRouteId
              });
            } else {
              history.push(to, {
                horizontalRoute: true,
                action: action,
                horizontalRouteId: _this.context.horizontalRouter.horizontalRouteId
              });
            }
          } else {
            if (replace) {
              history.replace(to);
            } else {
              history.push(to);
            }
          }
        }
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Link.prototype.render = function render() {
    var _props = this.props,
        replace = _props.replace,
        to = _props.to,
        innerRef = _props.innerRef,
        children = _props.children,
        horizontal = _props.horizontal,
        dontRenderComponent = _props.dontRenderComponent,
        props = _objectWithoutProperties(_props, ["replace", "to", "innerRef", "children", "horizontal", "dontRenderComponent"]);

    invariant(this.context.router, "You should not use <Link> outside a <Router>");

    warning(!(horizontal && !this.context.horizontalRouter), "Horizontal Link will not work outside a <HorizontalSwitch> component");

    invariant(to !== undefined, 'You must specify the "to" property');

    var history = this.context.router.history;

    var location = typeof to === "string" ? createLocation(to, null, null, history.location) : to;

    var href = history.createHref(location);
    if (React.isValidElement(this.props.children) && dontRenderComponent) {
      return React.cloneElement(children, { onClick: this.handleClick });
    }
    return React.createElement("a", _extends({}, props, {
      children: children,
      onClick: this.handleClick,
      href: href,
      ref: innerRef
    }));
  };

  return Link;
}(React.Component);

Link.propTypes = {
  onClick: PropTypes.func,
  children: PropTypes.node,
  target: PropTypes.string,
  horizontal: PropTypes.bool,
  dontRenderComponent: PropTypes.bool,
  replace: PropTypes.bool,
  to: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.bool]).isRequired,
  innerRef: PropTypes.oneOfType([PropTypes.string, PropTypes.func])
};
Link.defaultProps = {
  replace: false
};
Link.contextTypes = {
  router: PropTypes.shape({
    history: PropTypes.shape({
      push: PropTypes.func.isRequired,
      replace: PropTypes.func.isRequired,
      createHref: PropTypes.func.isRequired
    }).isRequired
  }).isRequired,
  horizontalRouter: PropTypes.shape({
    horizontalRouteId: PropTypes.number,
    prevPath: PropTypes.string
  })
};


export default Link;
